import { BatchSpanProcessorBase } from '../../../export/BatchSpanProcessorBase';
import { BufferConfig } from '../../../types';
export declare class BatchSpanProcessor extends BatchSpanProcessorBase<BufferConfig> {
    protected onShutdown(): void;
}
//# sourceMappingURL=BatchSpanProcessor.d.ts.map